@@ -28,19 +28,17 @@ class Paddle(pygame.sprite.Sprite):
                 self.rect = newpos
 
     def process_collision(self, b_rect, b_speed, paddle_type):
-        """
+        """Process a collision.
 
-        Parameters
-        ----------
-        b_rect : Ball rect
-        dx, dy : Ball speed along single axis
-        b_speed : Ball speed
+        Args:
+            b_rect : Ball rect
+            dx, dy : Ball speed along single axis
+            b_speed : Ball speed
 
-        Returns
-        -------
-        is_collision: 1 if ball collides with paddle
-        b_rect: new ball rect
-        b_speed: new ball speed
+        Returns:
+            is_collision: 1 if ball collides with paddle
+            b_rect: new ball rect
+            b_speed: new ball speed
 
         """
         if not self.rect.colliderect(b_rect):
