@@ -64,9 +64,10 @@ If an agent successfully connects four of their tokens, they will be rewarded 1
 
 import os
 
+import gymnasium
 import numpy as np
 import pygame
-from gym import spaces
+from gymnasium import spaces
 
 from pettingzoo import AECEnv
 from pettingzoo.utils import wrappers
@@ -85,8 +86,8 @@ def get_image(path):
     return sfc
 
 
-def env():
-    env = raw_env()
+def env(render_mode=None):
+    env = raw_env(render_mode=render_mode)
     env = wrappers.TerminateIllegalWrapper(env, illegal_reward=-1)
     env = wrappers.AssertOutOfBoundsWrapper(env)
     env = wrappers.OrderEnforcingWrapper(env)
@@ -101,7 +102,7 @@ class raw_env(AECEnv):
         "render_fps": 2,
     }
 
-    def __init__(self):
+    def __init__(self, render_mode=None):
         super().__init__()
         # 6 rows x 7 columns
         # blank space = 0
@@ -109,6 +110,7 @@ class raw_env(AECEnv):
         # agent 1 -- 2
         # flat representation in row major order
         self.screen = None
+        self.render_mode = render_mode
 
         self.board = [0] * (6 * 7)
 
@@ -202,6 +204,9 @@ class raw_env(AECEnv):
 
         self._accumulate_rewards()
 
+        if self.render_mode == "human":
+            self.render()
+
     def reset(self, seed=None, return_info=False, options=None):
         # reset environment
         self.board = [0] * (6 * 7)
@@ -217,17 +222,22 @@ class raw_env(AECEnv):
 
         self.agent_selection = self._agent_selector.reset()
 
-    def render(self, mode="human"):
+    def render(self):
+        if self.render_mode is None:
+            gymnasium.logger.WARN(
+                "You are calling render method without specifying any render mode."
+            )
+            return
+
         screen_width = 1287
         screen_height = 1118
-        if self.screen is None:
-            if mode == "human":
+        if self.render_mode == "human":
+            if self.screen is None:
                 pygame.init()
                 self.screen = pygame.display.set_mode((screen_width, screen_height))
-            else:
-                self.screen = pygame.Surface((screen_width, screen_height))
-        if mode == "human":
             pygame.event.get()
+        elif self.screen is None:
+            self.screen = pygame.Surface((screen_width, screen_height))
 
         # Load and scale all of the necessary images
         tile_size = (screen_width * (91 / 99)) / 7
@@ -268,13 +278,15 @@ class raw_env(AECEnv):
                     ),
                 )
 
-        if mode == "human":
+        if self.render_mode == "human":
             pygame.display.update()
 
         observation = np.array(pygame.surfarray.pixels3d(self.screen))
 
         return (
-            np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
+            np.transpose(observation, axes=(1, 0, 2))
+            if self.render_mode == "rgb_array"
+            else None
         )
 
     def close(self):
