@@ -95,9 +95,10 @@ whose turn it is. Taking an illegal move ends the game with a reward of -1 for t
 
 import os
 
+import gymnasium
 import numpy as np
 import pygame
-from gym import spaces
+from gymnasium import spaces
 
 from pettingzoo.utils import wrappers
 
@@ -139,7 +140,7 @@ class raw_env(RLCardBase):
         "render_fps": 1,
     }
 
-    def __init__(self, num_players=2):
+    def __init__(self, num_players=2, render_mode=None):
         super().__init__("no-limit-holdem", num_players, (54,))
         self.observation_spaces = self._convert_to_dict(
             [
@@ -166,7 +167,15 @@ class raw_env(RLCardBase):
             ]
         )
 
-    def render(self, mode="human"):
+        self.render_mode = render_mode
+
+    def render(self):
+        if self.render_mode is None:
+            gymnasium.logger.WARN(
+                "You are calling render method without specifying any render mode."
+            )
+            return
+
         def calculate_width(self, screen_width, i):
             return int(
                 (
@@ -191,15 +200,14 @@ class raw_env(RLCardBase):
             + np.ceil(len(self.possible_agents) / 2) * (screen_height * 1 / 2)
         )
 
-        if self.screen is None:
-            if mode == "human":
+        if self.render_mode == "human":
+            if self.screen is None:
                 pygame.init()
                 self.screen = pygame.display.set_mode((screen_width, screen_height))
-            else:
-                pygame.font.init()
-                self.screen = pygame.Surface((screen_width, screen_height))
-        if mode == "human":
             pygame.event.get()
+        elif self.screen is None:
+            pygame.font.init()
+            self.screen = pygame.Surface((screen_width, screen_height))
 
         # Setup dimensions for card size and setup for colors
         tile_size = screen_height * 2 / 10
@@ -394,11 +402,13 @@ class raw_env(RLCardBase):
                         ),
                     )
 
-        if mode == "human":
+        if self.render_mode == "human":
             pygame.display.update()
 
         observation = np.array(pygame.surfarray.pixels3d(self.screen))
 
         return (
-            np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
+            np.transpose(observation, axes=(1, 0, 2))
+            if self.render_mode == "rgb_array"
+            else None
         )
