@@ -1,4 +1,4 @@
-import gym
+import gymnasium
 
 from pettingzoo import AECEnv
 from pettingzoo.utils import wrappers
@@ -20,7 +20,7 @@ class raw_env(AECEnv):
 
     metadata = {"render_modes": ["human"], "name": "generated_agents_env_v0"}
 
-    def __init__(self, max_cycles=100):
+    def __init__(self, max_cycles=100, render_mode=None):
         super().__init__()
         self._obs_spaces = {}
         self._act_spaces = {}
@@ -28,6 +28,7 @@ class raw_env(AECEnv):
         self._agent_counters = {}
         self.max_cycles = max_cycles
         self.seed()
+        self.render_mode = render_mode
         for i in range(3):
             self.add_type()
 
@@ -44,8 +45,8 @@ class raw_env(AECEnv):
         type_id = len(self.types)
         num_actions = self.np_random.integers(3, 10)
         obs_size = self.np_random.integers(10, 50)
-        obs_space = gym.spaces.Box(low=0, high=1, shape=(obs_size,))
-        act_space = gym.spaces.Discrete(num_actions)
+        obs_space = gymnasium.spaces.Box(low=0, high=1, shape=(obs_size,))
+        act_space = gymnasium.spaces.Discrete(num_actions)
         new_type = f"type{type_id}"
         self.types.append(new_type)
         self._obs_spaces[new_type] = obs_space
@@ -82,7 +83,7 @@ class raw_env(AECEnv):
         self.agent_selection = self._agent_selector.reset()
 
     def seed(self, seed=None):
-        self.np_random, _ = gym.utils.seeding.np_random(seed)
+        self.np_random, _ = gymnasium.utils.seeding.np_random(seed)
 
     def step(self, action):
         if (
@@ -117,9 +118,16 @@ class raw_env(AECEnv):
 
         self._accumulate_rewards()
         self._deads_step_first()
+        if self.render_mode == "human":
+            self.render()
 
-    def render(self, mode="human"):
-        print(self.agents)
+    def render(self):
+        if self.render_mode is None:
+            gymnasium.logger.WARN(
+                "You are calling render method without specifying any render mode."
+            )
+        else:
+            print(self.agents)
 
     def close(self):
         pass
